This dataset consists of affection status, complex sampling weights, a binary stratifying variable, a binary environmental covariate, and SNP data.
LBL.ex2A data frame with variables: affected, wt,
stra, cov,
M1.1, M1.2, M2.1, M2.2, M3.1,
M3.2, M4.1, M4.2, M5.1, M5.2.