Learn R Programming

LBLGXE (version 1.4)

LBL.ex3: This dataset consists of two correlated affection statuses, no environmental covariate, and SNP data.

Description

This dataset consists of two correlated affection statuses, no environmental covariate, and SNP data.

Usage

LBL.ex3

Arguments

Format

A data frame with variables: Y1, Y2, M1.1, M1.2, M2.1, M2.2, M3.1, M3.2, M4.1, M4.2, M5.1, M5.2.